<?php
/**
 * interface DbAdapter
 *
 * @author Alcide_
 */
interface DbAdapter {

    /**
     * Retourne plusieurs enregistrements
     * @param DbSelect $sql
     * @return array l'ensemble des enregistrements
     */
    public function fetchAll(DbSelect $sql);
    
    /**
     * Retourne un seul enregistrement
     * @param DbSelect $sql
     * @return array les données d'un enregistrement
     */
    public function fetchOne(DbSelect $sql);
    
    /**
     * Mise à jour d'un enregistrement
     * @param string $tablename
     * @param array $data
     * @param string $where
     */
    public function update($tablename,array $data, $where);
    
    /**
     * Suppression d'un enregistrement
     * @param string $where
     */
    public function delete($where);
    
    /**
     * retour l'objet natif de connexion
     * @return mixed connection
     */
    public function getConnection();

    /**
     * toute autre méthode que doit fournir l'adapter 
     * et qui peut faire l'objet d'une implémentation différente selon le SGBD
     * - quoteSymbol
     * - listTable
     * - describeTable
     * - les methodes de transaction
     * - ...
     */
}